package com.amatellanes.android.examples;

import java.util.List;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.ImageView;
//import android.widget.ImageView;
import android.widget.TextView;

public class ItemAdapter extends BaseAdapter 
{
	// Definir les variables de la classe
	private Context context;
	private List<FitxaDades> items;

	// Definir el constructor de la classe (contexte, llista)
	public ItemAdapter(Context context, List<FitxaDades> items) 
	{
		this.context = context;
		this.items = items;
	}

	// Metode de retornar el numero d'elements
	@Override
	public int getCount() 
	{
		return this.items.size();
	}

	// Metode per llegir un element de la llista
	@Override
	public Object getItem(int position) 
	{
		return this.items.get(position);
	}

	// Metode per retornar la posicio actual
	@Override
	public long getItemId(int position) 
	{
		return position;
	}

	// Metode per crear la vista (View) que volem visualitzar dins del objecte
	// en el nostre cas el Listview
	@Override
	public View getView(int position, View convertView, ViewGroup parent) {
		
		// Recollir la informaci de la vista actual
		View rowView = convertView;

		// Si no existeix la vista actual (null), crear-ne una de nova a partir
		// del layout
		if (convertView == null) {
			// Crear un nou objecte de la llista a partir d'un recurs del layout XML
			LayoutInflater inflater = (LayoutInflater) context
					.getSystemService(Context.LAYOUT_INFLATER_SERVICE);
			rowView = inflater.inflate(R.layout.list_item, parent, false);
		}

		// Associar els elements del Layout amb el objectes
		ImageView ivFoto = (ImageView) rowView.findViewById(R.id.ivFoto);
		TextView tvNom = (TextView) rowView.findViewById(R.id.tvNom);
		TextView tvTelefon = (TextView) rowView.findViewById(R.id.tvTelefon);
		
		// Llegir els valors de la posici actual
		FitxaDades item = this.items.get(position);
		
		// Assignar els camps de Nom i Telefon
		tvNom.setText(item.getNom());
		tvTelefon.setText(item.getTelefon());
		
		// Si la imatge es null, asignar una imatge dels recursos, sino mostrar foto
		if(item.getImage()==null) 
		{
			ivFoto.setImageResource(R.drawable.icon_foto);
		}
		else
		{
			ivFoto.setImageBitmap(item.getImage());
		}
		
		// Retornar la vista que volem inserir dins del listview
		return rowView;
	}

}
