package com.amatellanes.android.examples;

import java.util.ArrayList;
import java.util.List;

import android.app.Activity;
import android.content.Intent;
import android.database.Cursor;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.os.Bundle;
import android.provider.ContactsContract;
import android.provider.ContactsContract.CommonDataKinds.Email;
import android.provider.ContactsContract.CommonDataKinds.Phone;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ListView;

public class MainActivity extends Activity
{

	// Definir variables
	private ListView listView;

	@Override
	protected void onCreate(Bundle savedInstanceState) 
	{
		super.onCreate(savedInstanceState);
		this.setContentView(R.layout.main);

		// Associar el listview del layout amb l'objecte
		listView = (ListView) findViewById(R.id.listView);
		
		// Crear el ArrayList de FitxaDades
		List<FitxaDades> items = new ArrayList<FitxaDades>();
				
		// Crear un cursor per accedir a l'agenda del telfon
		Cursor Telefons = getContentResolver().query(Phone.CONTENT_URI, null, null, null, null);
		
		// Fer un bucle per llegir TOTS els contactes
		while(Telefons.moveToNext())
		{
			// Llegir els elements Id, Nom, Telefon i email 
			String id = Telefons.getString(Telefons.getColumnIndex(Phone.CONTACT_ID));
			String nom = Telefons.getString(Telefons.getColumnIndex(Phone.DISPLAY_NAME));
			String tel = Telefons.getString(Telefons.getColumnIndex(Phone.NUMBER));
			String email="";

			// Llegir el ID de la foto
			int pic = Telefons.getInt(Telefons.getColumnIndex(Phone.PHOTO_ID));

			// Crear un cursor per accedir a la llistat dels correus dels contactes
			// en el cursor defefinir el ID com a parmetra
			Cursor emailCursor = getContentResolver().query(Email.CONTENT_URI,
							null, 
							Email.CONTACT_ID + " = ?", 
							new String[] { id }, 
							null);
			
			// Buscar quina es la columna que cont el Email
			int emailIdx = emailCursor.getColumnIndex(Email.DATA);
			
			// Situar-nos en el primer correu, i llegir-ne el valor
			if (emailCursor.moveToFirst()==true) 
			{
				// Llegir el correu en funci de la posici de la columna
                email = emailCursor.getString(emailIdx);
			}
			
			// Tancar el cursor
			emailCursor.close();
			
			// Llegir la imatge del contacte
			Bitmap bitmap = getImageContact(pic);

			// Crear un objecte del tipus FitxaDades per guardar els valors
			FitxaDades Contacte = new FitxaDades(id,nom,tel,email,pic,bitmap);
			
			// Assignar els valors en l'objecte
			items.add(Contacte);
						
		}
		
		// Tancar el cursos dels Telefons
		Telefons.close();

		// Associar en el ListView l'adaptador. Li passem el context i 
		// la llista de Contactes
		listView.setAdapter(new ItemAdapter(this, items));

		// Definir el Event click del listview
		listView.setOnItemClickListener(new AdapterView.OnItemClickListener() 
		{
			// Definir el metode Click de listView
			@Override
			public void onItemClick(AdapterView<?> adapter, View view,int position, long arg)
			{
					// Llegir informaci del Contacte sobre el que s'ha fet click
					// Utilitzar el getItem del Baseadapter per llegir segons la posici
					FitxaDades Contacte = (FitxaDades) listView.getAdapter().getItem(position);
					
					// Crear el Intent per accedir al detall
					Intent i = new Intent(getApplicationContext(),Detall_activity.class);
					
					// Definir els parametres
					i.putExtra("nom", Contacte.getNom());
					i.putExtra("email", Contacte.getEmail());
					i.putExtra("telefon", Contacte.getTelefon());
					
					// Llanar la activitat
					startActivity(i);
			}
		} );

	}

	
	// Funci per llegir la foto des de el ID
	private Bitmap getImageContact(int imageDataRow) 
	{
		
		// Crear un cursor i fer una consulta per el ID
	    Cursor cursorImage = getContentResolver().query(ContactsContract.Data.CONTENT_URI, 
	    		new String[] { ContactsContract.CommonDataKinds.Photo.PHOTO }, 
	    		ContactsContract.Data._ID + "=?", 
	    		new String[] { Integer.toString(imageDataRow) }, 
	    		null);
	    
	    // Crear un vector de byte per enmagatzemar la foto
	    byte[] imageBytes = null;
	    
	    // Si el cursos t un valor diferent a null vol dir que tenim foto de contacte
	    if (cursorImage != null) 
	    {
	    	// Situar-nos en el primer registre
	        if (cursorImage.moveToFirst()) 
	        {
	        	// Assignar el l'array de bytes en el vector
	            imageBytes = cursorImage.getBlob(0);
	        }
	        
	        // Tancar el cursosr
	        cursorImage.close();
	    }

	    // Si el vector t valors retornar-ho en format bitmap
	    if (imageBytes != null) 
	    {
	    	// Crear un bitmap a partir d'un vector de bytes image
	        return BitmapFactory.decodeByteArray(imageBytes, 0, imageBytes.length); 
	    } 
	    else 
	    {
	    	// Si no tenim cap informaci en el bitmap, retornar null
	        return null;
	    }
	}

}
